### QT StyleSheet templates ###
Themes available:
1. [Ubuntu](https://github.com/GTRONICK/QSS/blob/master/Ubuntu.qss)

![Ubuntu theme screenshot](https://sites.google.com/site/gtronick/QSS-Ubuntu.png)
    
2. [ElegantDark](https://github.com/GTRONICK/QSS/blob/master/ElegantDark.qss)

![ElegantDark theme screenshot](https://sites.google.com/site/gtronick/QSS-ElegantDark.png)
    
3. [MaterialDark](https://github.com/GTRONICK/QSS/blob/master/MaterialDark.qss)

![MaterialDark theme screenshot](https://sites.google.com/site/gtronick/QSS-MaterialDark.png)
    
4. [ConsoleStyle](https://github.com/GTRONICK/QSS/blob/master/ConsoleStyle.qss)

![ConsoleStyle theme screenshot](https://sites.google.com/site/gtronick/QSS-ConsoleStyle.png)
    
5. [AMOLED](https://github.com/GTRONICK/QSS/blob/master/AMOLED.qss)

![AMOLED theme screenshot](https://sites.google.com/site/gtronick/QSS-Amoled.png)
    
6. [Aqua](https://github.com/GTRONICK/QSS/blob/master/Aqua.qss)

![Aqua theme screenshot](https://sites.google.com/site/gtronick/QSS-Aqua.png)
    
Stay tunned!, this files are being updated frequently.

*Consider donating :)* **PayPal Account:** gtronick@gmail.com 

